@@ -42,13 +42,11 @@
 #'  }
 #' @useDynLib gastempt, .registration = TRUE
 #' @examples
-#' \donttest{
-#'  # Runs 30+ seconds on CRAN
-#'  dd = simulate_gastempt(n_records = 6, seed = 471)
-#'  d = dd$data
-#'  ret = stan_gastempt(d)
-#'  print(ret$coef)
-#'  }
+#' # Runs 30+ seconds on CRAN
+#' dd = simulate_gastempt(n_records = 6, seed = 471)
+#' d = dd$data
+#' ret = stan_gastempt(d)
+#' print(ret$coef)
 #' @import rstan
 #' @importFrom utils capture.output
 #' @export
@@ -121,7 +119,9 @@ stan_gastempt = function(d, model_name = "linexp_gastro_2b", lkj = 2,
     })
 
   plot = plot + geom_line(data = newdata, col = "#006400")  +
-    ggtitle(title, subtitle = comment(d))
+    ggtitle(title, subtitle = comment(d)) +
+    geom_vline(data = coef, aes(xintercept = t50), color = "lightgreen" )
+
 
   # Assemble return
   ret = list(coef = coef, fit = fit, plot = plot)
